==> rs485-4.0.0.tgz: rs485-4.0.0/include/mcua.h <==
#ifndef MCUA_H
#define MCUA_H
#ifdef __KERNEL__
	#include	"config.h"
#endif
#include	"version.h"
#include	"rsignal.h"

#ifdef __KERNEL__
#include <linux/version.h>
#undef KERN_2_6
#if(LINUX_VERSION_CODE > KERNEL_VERSION(2,6,0))
#define KERN_2_6 1
#endif
#endif

//  ioctl  mcua

#define RS_IOC_MAGIC			'j'
#define	RS_RESET			_IO(RS_IOC_MAGIC,0)
#define RS_BLNUMBER_RESET		_IO(RS_IOC_MAGIC,1)
#define	RS_GET_VERS			_IOR(RS_IOC_MAGIC,3,int)
#define RS_GET_DATAFIFO_SIZE		_IO(RS_IOC_MAGIC,5)
#define RS_SET_BAUDRATE			_IO(RS_IOC_MAGIC,6)
#define RS_GET_BAUDRATE			_IO(RS_IOC_MAGIC,7)
#define RS_FIFO_FLUSH			_IO(RS_IOC_MAGIC,8)
#define RS_IOC_MAXNR	8

#define	CACHE_MAXSIZE	(0x80)	// if > CACHE_MAXSIZE => Signal

#ifdef __KERNEL__
	#include	<asm/atomic.h>
	#include	<linux/serial_reg.h>
	#include	<linux/sched.h>
	#include	"ipc.h"

	typedef struct timeval	rs485_time_t;

/*  IPC device */
//VK	#define MAX_TASK_DEVICE		31
	#define MAX_TASK_DEVICE		32

	typedef struct _TASK_DEVICE_{ 			/*    */
		unsigned short		number; 		// 
		int 			round_count_prev;
	} TASK_DEVICE;

#endif

#include "success.h"

//     

#define 	RBYTE_WAIT		5		//	microseconds, ozhidanie baita 
#define		TBYTE_WAIT		5		//	microseconds (usec)
#define		TBYTE_TIMEOUT		500		//	microseconds (usec)
#define		RBYTE_TIMEOUT		500		//	microseconds (usec)

#ifdef __KERNEL__
/*   */
	#define MASK_CNT_PACKET     0x60	/*     */
	#define MASK_ADR_PACKET     0X1F	/*    */

/* */
	#define S_DATA_NAK		(0x8)
	#define S_FIFO_OVERFLOW		(0x40)

/*    */

	#define SWITCH_ADDRESSBYTE	1
	#define SWITCH_LENGTHBYTE	2
	#define SWITCH_DATABYTES	3
	#define SWITCH_REPLYBYTE	4
	#define SWITCH_OUTBYTES		6
	#define SWITCH_SIGNAL		5
	#define SWITCH_BADATA		7


/*    */
				//  
	#define FIRST       (UART_LCR_SPAR|UART_LCR_PARITY|UART_LCR_WLEN8)
				//   
	#define OTHER       (UART_LCR_SPAR|UART_LCR_EPAR|UART_LCR_PARITY|UART_LCR_WLEN8)


struct _STACK_BUFFER_INP_ {
	unsigned char		cache[CACHE_MAXSIZE];
	unsigned char		size;
	unsigned char		adr;
	unsigned char		signature;
};

struct _OUT_BUFFER_ {
	unsigned char	cache[CACHE_MAXSIZE];
	unsigned char	size;	
};

typedef struct _RS485_FIFO_ {
	char data_fifo[SIZE_STREAM_FIFO];
	volatile int data_wp;
	volatile int data_rp;
	atomic_t data_filled;		// skol'ko neschitannogo lezhit
	int nonblock;
#ifdef DECLARE_WAITQUEUE
	wait_queue_head_t	rs485_queue;
#else
	struct wait_queue	*rs485_queue;
#endif
} RS485FIFO;

typedef struct _RS485INFO_{
	unsigned short		usCountByteInp; //   
	unsigned short		usCountByteOut; //   
	unsigned char		tmp_byte;	//  
	long			lSection;	//  
	unsigned short		signal;
	long			status;

	/*   */

	unsigned short		usHopInp;	//   
	unsigned short		usHopOut;	//   
	unsigned short		use_mcua;
	unsigned short		interface_type;	//  
	/* IO */

	unsigned short		base;
	int			baudrate;

	/*  */

	struct semaphore	w_sem;
//  LPT- c c  c cc,    (FIFO),
// c,  c cc.
//  -c FIFO  c    cc    FIFO.
	struct semaphore	r_sem;

	TASK_DEVICE			device[MAX_TASK_DEVICE];
	struct _STACK_BUFFER_INP_	active_inbuf;
	struct _STACK_BUFFER_INP_	passive_inbuf;
	struct _OUT_BUFFER_		outbuffer;
	RS485FIFO			fifo;
} RS485INFO;

#endif

#endif

==> rs485-4.2.0.tgz: rs485-4.2.0/include/mcua.h <==
#ifndef MCUA_H
#define MCUA_H
#ifdef __KERNEL__
	#include	"config.h"
#endif
#include	"version.h"
#include	"rsignal.h"

#ifdef __KERNEL__
#include <linux/version.h>
#undef KERN_2_6
#if(LINUX_VERSION_CODE > KERNEL_VERSION(2,6,0))
#define KERN_2_6 1
#endif
#endif

//  ioctl  mcua

#define RS_IOC_MAGIC			'j'
#define	RS_RESET			_IO(RS_IOC_MAGIC,0)
#define RS_BLNUMBER_RESET		_IO(RS_IOC_MAGIC,1)
#define	RS_GET_VERS			_IOR(RS_IOC_MAGIC,3,int)
#define RS_GET_DATAFIFO_SIZE		_IO(RS_IOC_MAGIC,5)
#define RS_SET_BAUDRATE			_IO(RS_IOC_MAGIC,6)
#define RS_GET_BAUDRATE			_IO(RS_IOC_MAGIC,7)
#define RS_FIFO_FLUSH			_IO(RS_IOC_MAGIC,8)
#define RS_IOC_MAXNR	8

#define	CACHE_MAXSIZE	(0x80)	// if > CACHE_MAXSIZE => Signal

#ifdef __KERNEL__
	#include	<asm/atomic.h>
	#include	<linux/serial_reg.h>
	#include	<linux/sched.h>
	#include	"ipc.h"

	typedef struct timeval	rs485_time_t;

/*  IPC device */
//VK	#define MAX_TASK_DEVICE		31
	#define MAX_TASK_DEVICE		32

	typedef struct _TASK_DEVICE_{ 			/*    */
		unsigned short		number; 		// 
		int 			round_count_prev;
	} TASK_DEVICE;

#endif

#include "success.h"

//     

#define 	RBYTE_WAIT		5		//	microseconds, ozhidanie baita 
#define		TBYTE_WAIT		5		//	microseconds (usec)
#define		TBYTE_TIMEOUT		250		// 500	microseconds (usec)
#define		RBYTE_TIMEOUT		250		// 500	microseconds (usec)
#define         SEM_WAIT                100             //      microseconds (usec) zaderzhka pered otkrytiem semafora  
#ifdef __KERNEL__
/*   */
	#define MASK_CNT_PACKET     0x60	/*     */
	#define MASK_ADR_PACKET     0X1F	/*    */

/* */
	#define S_DATA_NAK		(0x8)
	#define S_FIFO_OVERFLOW		(0x40)

/*    */

	#define SECT_ADDRESSBYTE	1
	#define SECT_LENGTHBYTE	2
	#define SECT_DATABYTES	3
	#define SECT_REPLYBYTE	4
	#define SECT_OUTBYTES		6
	#define SECT_SIGNAL		5
	#define SECT_BADATA		7


/*    */
				//  
	#define FIRST       (UART_LCR_SPAR|UART_LCR_PARITY|UART_LCR_WLEN8)
				//   
	#define OTHER       (UART_LCR_SPAR|UART_LCR_EPAR|UART_LCR_PARITY|UART_LCR_WLEN8)


struct _STACK_BUFFER_INP_ {
	unsigned char		cache[CACHE_MAXSIZE];
	unsigned char		size;
	unsigned char		adr;
	unsigned char		signature;
};

struct _OUT_BUFFER_ {
	unsigned char	cache[CACHE_MAXSIZE];
	unsigned char	size;	
};

typedef struct _RS485_FIFO_ {
	char data_fifo[SIZE_STREAM_FIFO];
	volatile int data_wp;
	volatile int data_rp;
	atomic_t data_filled;		// skol'ko neschitannogo lezhit
	int nonblock;
#ifdef DECLARE_WAITQUEUE
	wait_queue_head_t	rs485_queue;
#else
	struct wait_queue	*rs485_queue;
#endif
} RS485FIFO;

typedef struct _RS485INFO_{
	unsigned short		usCountByteInp; //   
	unsigned short		usCountByteOut; //   
	unsigned char		tmp_byte;	//  
	long			lSection;	//  
	unsigned short		signal;
	long			status;

	/*   */

	unsigned short		usHopInp;	//   
	unsigned short		usHopOut;	//   
	unsigned short		use_mcua;
	unsigned short		interface_type;	//  
	/* IO */

	unsigned short		base;
	int			baudrate;

	/*  */

	struct semaphore	sem;
//  LPT- c c  c cc,    (FIFO),
// c,  c cc.
//  -c FIFO  c    cc    FIFO.

	TASK_DEVICE			device[MAX_TASK_DEVICE];
	struct _STACK_BUFFER_INP_	active_inbuf;
	struct _STACK_BUFFER_INP_	passive_inbuf;
	struct _OUT_BUFFER_		outbuffer;
	RS485FIFO			fifo;
} RS485INFO;

#endif

#endif
